<template>
  <div class="app-container">
    <!-- 对话框(添加 / 修改) -->
    <el-dialog :title="dialogTitle" :visible.sync="dialogVisible" width="45%" v-dialogDrag
               append-to-body>
      <el-form ref="formRef" :model="formData" :rules="formRules" v-loading="formLoading"
               label-width="100px">
        <el-form-item label="问题模板id" prop="templateId">
          <el-input v-model="formData.templateId" placeholder="请输入问题模板id"/>
        </el-form-item>
        <el-form-item label="key" prop="settingKey">
          <el-input v-model="formData.settingKey" placeholder="请输入key"/>
        </el-form-item>
        <el-form-item label="参数名称" prop="settingName">
          <el-input v-model="formData.settingName" placeholder="请输入参数名称"/>
        </el-form-item>
        <el-form-item label="参数默认值" prop="settingValue">
          <el-input v-model="formData.settingValue" placeholder="请输入参数默认值"/>
        </el-form-item>
        <el-form-item label="排序" prop="sort">
          <el-input v-model="formData.sort" placeholder="请输入排序"/>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm" :disabled="formLoading">确 定</el-button>
        <el-button @click="dialogVisible = false">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import * as QuestionParamSettingApi from '@/api/ai/questionparamsetting';

export default {
  name: "QuestionParamSettingForm",
  components: {},
  data() {
    return {
      // 弹出层标题
      dialogTitle: "",
      // 是否显示弹出层
      dialogVisible: false,
      // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
      formLoading: false,
      // 表单参数
      formData: {
        id: undefined,
        templateId: undefined,
        settingKey: undefined,
        settingName: undefined,
        settingValue: undefined,
        sort: undefined,
      },
      // 表单校验
      formRules: {
        templateId: [{required: true, message: '问题模板id不能为空', trigger: 'blur'}],
      },
    };
  },
  methods: {
    /** 打开弹窗 */
    async open(id) {
      this.dialogVisible = true;
      this.reset();
      // 修改时，设置数据
      if (id) {
        this.formLoading = true;
        try {
          const res = await QuestionParamSettingApi.getQuestionParamSetting(id);
          this.formData = res.data;
          this.title = "修改大模型问题设置参数";
        } finally {
          this.formLoading = false;
        }
      }
      this.title = "新增大模型问题设置参数";
    },
    /** 提交按钮 */
    async submitForm() {
      // 校验主表
      await this.$refs["formRef"].validate();
      this.formLoading = true;
      try {
        const data = this.formData;
        // 修改的提交
        if (data.id) {
          await QuestionParamSettingApi.updateQuestionParamSetting(data);
          this.$modal.msgSuccess("修改成功");
          this.dialogVisible = false;
          this.$emit('success');
          return;
        }
        // 添加的提交
        await QuestionParamSettingApi.createQuestionParamSetting(data);
        this.$modal.msgSuccess("新增成功");
        this.dialogVisible = false;
        this.$emit('success');
      } finally {
        this.formLoading = false;
      }
    },
    /** 表单重置 */
    reset() {
      this.formData = {
        id: undefined,
        templateId: undefined,
        settingKey: undefined,
        settingName: undefined,
        settingValue: undefined,
        sort: undefined,
      };
      this.resetForm("formRef");
    }
  }
};
</script>
